set termout on
set echo on
spool emptyexample.log

-- demonstrates that the 11g automatic stats job does not gather statistics on empty subpartitions

-- drop and recreate subpartitioned table using range partitioning, interval partitioning,
-- and subpartitioning

DROP TABLE TEST;

CREATE TABLE TEST
(
  PRCS_DT DATE,
  DIV_NBR NUMBER
)
PARTITION BY RANGE (PRCS_DT)
INTERVAL( NUMTODSINTERVAL(7,'DAY'))
SUBPARTITION BY LIST (DIV_NBR)
SUBPARTITION TEMPLATE
  (SUBPARTITION S1 VALUES (1),
   SUBPARTITION S2 VALUES (2))
(  
  PARTITION P20110717 VALUES LESS THAN (TO_DATE('2011-07-17', 'YYYY-MM-DD')),
  PARTITION P20120101 VALUES LESS THAN (TO_DATE('2012-01-01', 'YYYY-MM-DD'))
);

-- insert a row so that one of the subpartitions has a row and the other three do not

insert into test values (TO_DATE('2011-07-18', 'YYYY-MM-DD'),1);

commit;

-- open today's window to kick off stats job and wait

execute DBMS_SCHEDULER.OPEN_WINDOW ('THURSDAY_WINDOW',NULL);

execute DBMS_LOCK.SLEEP (60);

execute DBMS_SCHEDULER.CLOSE_WINDOW ('THURSDAY_WINDOW');

-- table and partitions have non-null num_rows and last_analyzed

select num_rows,last_analyzed from user_tables where table_name='TEST';

select partition_name,num_rows,last_analyzed from user_tab_partitions where table_name='TEST';

-- empty subpartitions have null num_rows and last_analyzed

select subpartition_name,num_rows,last_analyzed from user_tab_subpartitions where table_name='TEST';

spool off
